@@ -7,6 +7,7 @@ import threading
 from bs4 import BeautifulSoup
 import requests
 import re
+import time
 
 name = 'telegram_util'
 
@@ -17,6 +18,8 @@ class AlbumResult(object):
 		self.video = ''
 		self.cap_html = '' # weibo status only
 		self.title = '' # weibo status only
+		self.wid = '' # weibo status only 
+		self.rwid = '' # weibo status only retweet id
 
 	def empty(self):
 		return (not self.imgs) and (not self.cap) and (not self.video)
@@ -24,11 +27,9 @@ class AlbumResult(object):
 	def __str__(self):
 		return '\t'.join([k + ':' + str(v) for (k,v) in self.__dict__.items() if v])
 
-def cleanUrl(text):
-	for special_char in ['https://', 'http://']:
-		text = text.replace(special_char, '')
-	text = text.replace('  ', ' ')
+def compactText(text):
 	for _ in range(10):
+		text = text.replace('  ', ' ')
 		text = text.replace('\n ', '\n')
 		text = text.replace(' \n', '\n')
 	for _ in range(10):	
@@ -47,9 +48,10 @@ def escapeMarkdown(text):
 			r.append("\\")
 		r.append(x)
 	text = ''.join(r)
-	for special_char in ['`', '*']:
+	for special_char in ['`', '*', 'https://', 'http://']:
 		text = text.replace(special_char, '')
-	return cleanUrl(text)
+	text.replace('t.cn/', ' t.cn/')
+	return compactText(text)
 
 def getWid(url):
 	url = clearUrl(url)
@@ -160,7 +162,39 @@ def autoDestroy(msg, minutes=1):
 	if msg.chat_id > 0:
 		return
 	threading.Timer(minutes * 60, lambda: tryDelete(msg)).start() 
-	
+
+class TimedDeleter():
+	def __init__(self):
+		self.queue = []
+		self.scheduled = False
+
+	def delete(self, msg, minutes=0):
+		if minutes < 0.1:
+			return tryDelete(msg)
+		delete_time = time.time() + 60 * minutes
+		self.queue.append((delete_time, msg))
+		if not self.scheduled:
+			self.scheduled = True
+			print('schedule')
+			threading.Timer(minutes * 60 + 30, lambda: self.process).start() 
+
+	def process(self):
+		print('process')
+		new_queue = []
+		while self.queue:
+			t, msg = self.queue.pop()
+			if t < time.time():
+				tryDelete(msg)
+			else:
+				new_queue.append((t, msg))
+		self.queue = new_queue
+		if not self.queue:
+			print('end process')
+			self.scheduled = False
+			return
+		self.queue.sort()
+		threading.Timer(self.queue[0] - time.time() + 30, lambda: self.process).start() 
+
 def matchKey(t, keys):
 	if not t:
 		return False
@@ -243,7 +277,7 @@ def getLinkFromMsg(msg):
 			return url
 
 def clearUrl(url):
-	for end_char in ['/?utm_source']:
+	for end_char in ['/?utm_source', '?mblogid']:
 		url = url.split(end_char)[0]
 	for end_char in ['#']:
 		if 'id=' not in url:
